Class: Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1LogoRecognitionAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p1beta1/classes.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb

Overview

Annotation corresponding to one detected, tracked and recognized logo class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1LogoRecognitionAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1LogoRecognitionAnnotation.



475
476
477
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 475

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entityGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



461
462
463
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 461

def entity
  @entity
end

#segmentsArray<Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1VideoSegment>

All video segments where the recognized logo appears. There might be multiple instances of the same logo class appearing in one VideoSegment. Corresponds to the JSON property segments



467
468
469
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 467

def segments
  @segments
end

#tracksArray<Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1Track>

All logo tracks where the recognized logo appears. Each track corresponds to one logo instance appearing in consecutive frames. Corresponds to the JSON property tracks



473
474
475
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 473

def tracks
  @tracks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



480
481
482
483
484
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 480

def update!(**args)
  @entity = args[:entity] if args.key?(:entity)
  @segments = args[:segments] if args.key?(:segments)
  @tracks = args[:tracks] if args.key?(:tracks)
end