Class: Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1SpeechTranscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p1beta1/classes.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb

Overview

A speech recognition result corresponding to a portion of the audio.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1SpeechTranscription

Returns a new instance of GoogleCloudVideointelligenceV1SpeechTranscription.



741
742
743
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 741

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alternativesArray<Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1SpeechRecognitionAlternative>

May contain one or more recognition hypotheses (up to the maximum specified in max_alternatives). These alternatives are ordered in terms of accuracy, with the top (first) alternative being the most probable, as ranked by the recognizer. Corresponds to the JSON property alternatives



732
733
734
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 732

def alternatives
  @alternatives
end

#language_codeString

Output only. The BCP-47 language tag of the language in this result. This language code was detected to have the most likelihood of being spoken in the audio. Corresponds to the JSON property languageCode

Returns:

  • (String)


739
740
741
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 739

def language_code
  @language_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



746
747
748
749
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 746

def update!(**args)
  @alternatives = args[:alternatives] if args.key?(:alternatives)
  @language_code = args[:language_code] if args.key?(:language_code)
end