Class: Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1VideoAnnotationProgress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p1beta1/classes.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb

Overview

Annotation progress for a single video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1VideoAnnotationProgress

Returns a new instance of GoogleCloudVideointelligenceV1VideoAnnotationProgress.



968
969
970
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_statusGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1ExportToOutputUriStatus

Status of exporting annotation response to user specified output_uri. Corresponds to the JSON property exportStatus



934
935
936
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 934

def export_status
  @export_status
end

#featureString

Specifies which feature is being tracked if the request contains more than one feature. Corresponds to the JSON property feature

Returns:

  • (String)


940
941
942
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 940

def feature
  @feature
end

#input_uriString

Video file location in Cloud Storage. Corresponds to the JSON property inputUri

Returns:

  • (String)


945
946
947
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 945

def input_uri
  @input_uri
end

#progress_percentFixnum

Approximate percentage processed thus far. Guaranteed to be 100 when fully processed. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


951
952
953
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 951

def progress_percent
  @progress_percent
end

#segmentGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1VideoSegment

Video segment. Corresponds to the JSON property segment



956
957
958
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 956

def segment
  @segment
end

#start_timeString

Time when the request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


961
962
963
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 961

def start_time
  @start_time
end

#update_timeString

Time of the most recent update. Corresponds to the JSON property updateTime

Returns:

  • (String)


966
967
968
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 966

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



973
974
975
976
977
978
979
980
981
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 973

def update!(**args)
  @export_status = args[:export_status] if args.key?(:export_status)
  @feature = args[:feature] if args.key?(:feature)
  @input_uri = args[:input_uri] if args.key?(:input_uri)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @segment = args[:segment] if args.key?(:segment)
  @start_time = args[:start_time] if args.key?(:start_time)
  @update_time = args[:update_time] if args.key?(:update_time)
end