Class: Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1beta2DetectedLandmark

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p1beta1/classes.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb

Overview

A generic detected landmark represented by name in string format and a 2D location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2DetectedLandmark

Returns a new instance of GoogleCloudVideointelligenceV1beta2DetectedLandmark.



1309
1310
1311
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 1309

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

The confidence score of the detected landmark. Range [0, 1]. Corresponds to the JSON property confidence

Returns:

  • (Float)


1296
1297
1298
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 1296

def confidence
  @confidence
end

#nameString

The name of this landmark, for example, left_hand, right_shoulder. Corresponds to the JSON property name

Returns:

  • (String)


1301
1302
1303
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 1301

def name
  @name
end

#pointGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1beta2NormalizedVertex

A vertex represents a 2D point in the image. NOTE: the normalized vertex coordinates are relative to the original image and range from 0 to 1. Corresponds to the JSON property point



1307
1308
1309
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 1307

def point
  @point
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1314
1315
1316
1317
1318
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 1314

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @name = args[:name] if args.key?(:name)
  @point = args[:point] if args.key?(:point)
end