Class: Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1FaceDetectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p1beta1/classes.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb

Overview

Config for FACE_DETECTION.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1FaceDetectionConfig

Returns a new instance of GoogleCloudVideointelligenceV1p1beta1FaceDetectionConfig.



2798
2799
2800
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2798

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_attributesBoolean Also known as: include_attributes?

Whether to enable face attributes detection, such as glasses, dark_glasses, mouth_open etc. Ignored if 'include_bounding_boxes' is set to false. Corresponds to the JSON property includeAttributes

Returns:

  • (Boolean)


2783
2784
2785
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2783

def include_attributes
  @include_attributes
end

#include_bounding_boxesBoolean Also known as: include_bounding_boxes?

Whether bounding boxes are included in the face annotation output. Corresponds to the JSON property includeBoundingBoxes

Returns:

  • (Boolean)


2789
2790
2791
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2789

def include_bounding_boxes
  @include_bounding_boxes
end

#modelString

Model to use for face detection. Supported values: "builtin/stable" (the default if unset) and "builtin/latest". Corresponds to the JSON property model

Returns:

  • (String)


2796
2797
2798
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2796

def model
  @model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2803
2804
2805
2806
2807
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2803

def update!(**args)
  @include_attributes = args[:include_attributes] if args.key?(:include_attributes)
  @include_bounding_boxes = args[:include_bounding_boxes] if args.key?(:include_bounding_boxes)
  @model = args[:model] if args.key?(:model)
end