Class: Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1LabelAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p1beta1/classes.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb

Overview

Label annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1LabelAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p1beta1LabelAnnotation.



2887
2888
2889
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_entitiesArray<Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1Entity>

Common categories for the detected entity. For example, when the label is Terrier, the category is likely dog. And in some cases there might be more than one categories e.g., Terrier could also be a pet. Corresponds to the JSON property categoryEntities



2865
2866
2867
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2865

def category_entities
  @category_entities
end

#entityGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



2870
2871
2872
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2870

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1LabelFrame>

All video frames where a label was detected. Corresponds to the JSON property frames



2875
2876
2877
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2875

def frames
  @frames
end

#segmentsArray<Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1LabelSegment>

All video segments where a label was detected. Corresponds to the JSON property segments



2880
2881
2882
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2880

def segments
  @segments
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


2885
2886
2887
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2885

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2892
2893
2894
2895
2896
2897
2898
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2892

def update!(**args)
  @category_entities = args[:category_entities] if args.key?(:category_entities)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segments = args[:segments] if args.key?(:segments)
  @version = args[:version] if args.key?(:version)
end