Class: Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p1beta1/classes.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb

Overview

Annotation corresponding to one detected, tracked and recognized logo class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation.



3029
3030
3031
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entityGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



3015
3016
3017
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3015

def entity
  @entity
end

#segmentsArray<Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1VideoSegment>

All video segments where the recognized logo appears. There might be multiple instances of the same logo class appearing in one VideoSegment. Corresponds to the JSON property segments



3021
3022
3023
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3021

def segments
  @segments
end

#tracksArray<Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1Track>

All logo tracks where the recognized logo appears. Each track corresponds to one logo instance appearing in consecutive frames. Corresponds to the JSON property tracks



3027
3028
3029
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3027

def tracks
  @tracks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3034
3035
3036
3037
3038
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3034

def update!(**args)
  @entity = args[:entity] if args.key?(:entity)
  @segments = args[:segments] if args.key?(:segments)
  @tracks = args[:tracks] if args.key?(:tracks)
end