Class: Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1VideoAnnotationProgress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p1beta1/classes.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb

Overview

Annotation progress for a single video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1VideoAnnotationProgress

Returns a new instance of GoogleCloudVideointelligenceV1p1beta1VideoAnnotationProgress.



3755
3756
3757
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_statusGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1ExportToOutputUriStatus

Status of exporting annotation response to user specified output_uri. Corresponds to the JSON property exportStatus



3721
3722
3723
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3721

def export_status
  @export_status
end

#featureString

Specifies which feature is being tracked if the request contains more than one feature. Corresponds to the JSON property feature

Returns:

  • (String)


3727
3728
3729
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3727

def feature
  @feature
end

#input_uriString

Video file location in Cloud Storage. Corresponds to the JSON property inputUri

Returns:

  • (String)


3732
3733
3734
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3732

def input_uri
  @input_uri
end

#progress_percentFixnum

Approximate percentage processed thus far. Guaranteed to be 100 when fully processed. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


3738
3739
3740
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3738

def progress_percent
  @progress_percent
end

#segmentGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1VideoSegment

Video segment. Corresponds to the JSON property segment



3743
3744
3745
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3743

def segment
  @segment
end

#start_timeString

Time when the request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


3748
3749
3750
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3748

def start_time
  @start_time
end

#update_timeString

Time of the most recent update. Corresponds to the JSON property updateTime

Returns:

  • (String)


3753
3754
3755
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3753

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3760
3761
3762
3763
3764
3765
3766
3767
3768
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3760

def update!(**args)
  @export_status = args[:export_status] if args.key?(:export_status)
  @feature = args[:feature] if args.key?(:feature)
  @input_uri = args[:input_uri] if args.key?(:input_uri)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @segment = args[:segment] if args.key?(:segment)
  @start_time = args[:start_time] if args.key?(:start_time)
  @update_time = args[:update_time] if args.key?(:update_time)
end