Class: Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1VideoContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p1beta1/classes.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb

Overview

Video context and/or feature-specific parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1VideoContext

Returns a new instance of GoogleCloudVideointelligenceV1p1beta1VideoContext.



3957
3958
3959
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explicit_content_detection_configGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1ExplicitContentDetectionConfig

Config for EXPLICIT_CONTENT_DETECTION. Corresponds to the JSON property explicitContentDetectionConfig



3913
3914
3915
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3913

def explicit_content_detection_config
  @explicit_content_detection_config
end

#face_detection_configGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1FaceDetectionConfig

Config for FACE_DETECTION. Corresponds to the JSON property faceDetectionConfig



3918
3919
3920
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3918

def face_detection_config
  @face_detection_config
end

#label_detection_configGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1LabelDetectionConfig

Config for LABEL_DETECTION. Corresponds to the JSON property labelDetectionConfig



3923
3924
3925
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3923

def label_detection_config
  @label_detection_config
end

#object_tracking_configGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1ObjectTrackingConfig

Config for OBJECT_TRACKING. Corresponds to the JSON property objectTrackingConfig



3928
3929
3930
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3928

def object_tracking_config
  @object_tracking_config
end

#person_detection_configGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1PersonDetectionConfig

Config for PERSON_DETECTION. Corresponds to the JSON property personDetectionConfig



3933
3934
3935
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3933

def person_detection_config
  @person_detection_config
end

#segmentsArray<Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1VideoSegment>

Video segments to annotate. The segments may overlap and are not required to be contiguous or span the whole video. If unspecified, each video is treated as a single segment. Corresponds to the JSON property segments



3940
3941
3942
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3940

def segments
  @segments
end

#shot_change_detection_configGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1ShotChangeDetectionConfig

Config for SHOT_CHANGE_DETECTION. Corresponds to the JSON property shotChangeDetectionConfig



3945
3946
3947
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3945

def shot_change_detection_config
  @shot_change_detection_config
end

#speech_transcription_configGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1SpeechTranscriptionConfig

Config for SPEECH_TRANSCRIPTION. Corresponds to the JSON property speechTranscriptionConfig



3950
3951
3952
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3950

def speech_transcription_config
  @speech_transcription_config
end

#text_detection_configGoogle::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1p1beta1TextDetectionConfig

Config for TEXT_DETECTION. Corresponds to the JSON property textDetectionConfig



3955
3956
3957
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3955

def text_detection_config
  @text_detection_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3962
3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 3962

def update!(**args)
  @explicit_content_detection_config = args[:explicit_content_detection_config] if args.key?(:explicit_content_detection_config)
  @face_detection_config = args[:face_detection_config] if args.key?(:face_detection_config)
  @label_detection_config = args[:label_detection_config] if args.key?(:label_detection_config)
  @object_tracking_config = args[:object_tracking_config] if args.key?(:object_tracking_config)
  @person_detection_config = args[:person_detection_config] if args.key?(:person_detection_config)
  @segments = args[:segments] if args.key?(:segments)
  @shot_change_detection_config = args[:shot_change_detection_config] if args.key?(:shot_change_detection_config)
  @speech_transcription_config = args[:speech_transcription_config] if args.key?(:speech_transcription_config)
  @text_detection_config = args[:text_detection_config] if args.key?(:text_detection_config)
end