Class: Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1beta2WordInfo
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p1beta1::GoogleCloudVideointelligenceV1beta2WordInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p1beta1/classes.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb,
lib/google/apis/videointelligence_v1p1beta1/representations.rb
Overview
Word-specific information for recognized words. Word information is only
included in the response when certain request parameters are set, such as
enable_word_time_offsets.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
Output only.
-
#end_time ⇒ String
Time offset relative to the beginning of the audio, and corresponding to the end of the spoken word.
-
#speaker_label ⇒ String
Output only.
-
#speaker_tag ⇒ Fixnum
Output only.
-
#start_time ⇒ String
Time offset relative to the beginning of the audio, and corresponding to the start of the spoken word.
-
#word ⇒ String
The word corresponding to this set of information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2WordInfo
constructor
A new instance of GoogleCloudVideointelligenceV1beta2WordInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2WordInfo
Returns a new instance of GoogleCloudVideointelligenceV1beta2WordInfo.
2386 2387 2388 |
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2386 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
Output only. The confidence estimate between 0.0 and 1.0. A higher number
indicates an estimated greater likelihood that the recognized words are
correct. This field is set only for the top alternative. This field is not
guaranteed to be accurate and users should not rely on it to be always
provided. The default of 0.0 is a sentinel value indicating confidence was
not set.
Corresponds to the JSON property confidence
2348 2349 2350 |
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2348 def confidence @confidence end |
#end_time ⇒ String
Time offset relative to the beginning of the audio, and corresponding to the
end of the spoken word. This field is only set if enable_word_time_offsets=
true and only in the top hypothesis. This is an experimental feature and the
accuracy of the time offset can vary.
Corresponds to the JSON property endTime
2356 2357 2358 |
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2356 def end_time @end_time end |
#speaker_label ⇒ String
Output only. A distinct string value is assigned for every speaker within the
audio. This field specifies which one of those speakers was detected to have
spoken this word.
Corresponds to the JSON property speakerLabel
2363 2364 2365 |
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2363 def speaker_label @speaker_label end |
#speaker_tag ⇒ Fixnum
Output only. A distinct integer value is assigned for every speaker within the
audio. This field specifies which one of those speakers was detected to have
spoken this word. Value ranges from 1 up to diarization_speaker_count, and is
only set if speaker diarization is enabled.
Corresponds to the JSON property speakerTag
2371 2372 2373 |
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2371 def speaker_tag @speaker_tag end |
#start_time ⇒ String
Time offset relative to the beginning of the audio, and corresponding to the
start of the spoken word. This field is only set if enable_word_time_offsets=
true and only in the top hypothesis. This is an experimental feature and the
accuracy of the time offset can vary.
Corresponds to the JSON property startTime
2379 2380 2381 |
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2379 def start_time @start_time end |
#word ⇒ String
The word corresponding to this set of information.
Corresponds to the JSON property word
2384 2385 2386 |
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2384 def word @word end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2391 2392 2393 2394 2395 2396 2397 2398 |
# File 'lib/google/apis/videointelligence_v1p1beta1/classes.rb', line 2391 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @end_time = args[:end_time] if args.key?(:end_time) @speaker_label = args[:speaker_label] if args.key?(:speaker_label) @speaker_tag = args[:speaker_tag] if args.key?(:speaker_tag) @start_time = args[:start_time] if args.key?(:start_time) @word = args[:word] if args.key?(:word) end |